@@ -49,8 +49,6 @@ struct LabelProperties : WidgetProperties
             label->setAutoSize(parseBoolean(value, true));
         else if (property == "MaximumTextWidth")
             label->setMaximumTextWidth(value.toFloat());
-        else if (property == "IgnoreMouseEvents")
-            label->ignoreMouseEvents(parseBoolean(value, false));
         else
             WidgetProperties::updateProperty(widget, property, value);
     }
@@ -66,7 +64,6 @@ struct LabelProperties : WidgetProperties
         pair.first["ScrollbarPolicy"] = {"Enum{Automatic,Always,Never}", serializeScrollbarPolicy(label->getScrollbarPolicy())};
         pair.first["AutoSize"] = {"Bool", tgui::Serializer::serialize(label->getAutoSize())};
         pair.first["MaximumTextWidth"] = {"Float", tgui::String::fromNumber(label->getMaximumTextWidth())};
-        pair.first["IgnoreMouseEvents"] = {"Bool", tgui::Serializer::serialize(label->isIgnoringMouseEvents())};
 
         const auto renderer = label->getSharedRenderer();
         pair.second["Borders"] = {"Outline", renderer->getBorders().toString()};
@@ -81,50 +78,6 @@ struct LabelProperties : WidgetProperties
         pair.second["ScrollbarWidth"] = {"Float", tgui::String::fromNumber(renderer->getScrollbarWidth())};
         return pair;
     }
-
-private:
-
-    TGUI_NODISCARD static tgui::Label::HorizontalAlignment deserializeHorizontalAlignment(tgui::String value)
-    {
-        value = value.trim().toLower();
-        if (value == "right")
-            return tgui::Label::HorizontalAlignment::Right;
-        else if (value == "center")
-            return tgui::Label::HorizontalAlignment::Center;
-        else
-            return tgui::Label::HorizontalAlignment::Left;
-    }
-
-    TGUI_NODISCARD static tgui::Label::VerticalAlignment deserializeVerticalAlignment(tgui::String value)
-    {
-        value = value.trim().toLower();
-        if (value == "bottom")
-            return tgui::Label::VerticalAlignment::Bottom;
-        else if (value == "center")
-            return tgui::Label::VerticalAlignment::Center;
-        else
-            return tgui::Label::VerticalAlignment::Top;
-    }
-
-    TGUI_NODISCARD static tgui::String serializeHorizontalAlignment(tgui::Label::HorizontalAlignment alignment)
-    {
-        if (alignment == tgui::Label::HorizontalAlignment::Center)
-            return "Center";
-        else if (alignment == tgui::Label::HorizontalAlignment::Right)
-            return "Right";
-        else
-            return "Left";
-    }
-
-    TGUI_NODISCARD static tgui::String serializeVerticalAlignment(tgui::Label::VerticalAlignment alignment)
-    {
-        if (alignment == tgui::Label::VerticalAlignment::Center)
-            return "Center";
-        else if (alignment == tgui::Label::VerticalAlignment::Bottom)
-            return "Bottom";
-        else
-            return "Top";
-    }
 };
 
 #endif // TGUI_GUI_BUILDER_LABEL_PROPERTIES_HPP
