@@ -22,7 +22,6 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-
 #include <TGUI/Backend/Window/SDL/BackendGuiSDL.hpp>
 #include <TGUI/Backend/Window/SDL/BackendSDL.hpp>
 
@@ -45,6 +44,34 @@ namespace tgui
     {
         switch (key)
         {
+#if SDL_MAJOR_VERSION >= 3
+        case SDLK_A:            return Event::KeyboardKey::A;
+        case SDLK_B:            return Event::KeyboardKey::B;
+        case SDLK_C:            return Event::KeyboardKey::C;
+        case SDLK_D:            return Event::KeyboardKey::D;
+        case SDLK_E:            return Event::KeyboardKey::E;
+        case SDLK_F:            return Event::KeyboardKey::F;
+        case SDLK_G:            return Event::KeyboardKey::G;
+        case SDLK_H:            return Event::KeyboardKey::H;
+        case SDLK_I:            return Event::KeyboardKey::I;
+        case SDLK_J:            return Event::KeyboardKey::J;
+        case SDLK_K:            return Event::KeyboardKey::K;
+        case SDLK_L:            return Event::KeyboardKey::L;
+        case SDLK_M:            return Event::KeyboardKey::M;
+        case SDLK_N:            return Event::KeyboardKey::N;
+        case SDLK_O:            return Event::KeyboardKey::O;
+        case SDLK_P:            return Event::KeyboardKey::P;
+        case SDLK_Q:            return Event::KeyboardKey::Q;
+        case SDLK_R:            return Event::KeyboardKey::R;
+        case SDLK_S:            return Event::KeyboardKey::S;
+        case SDLK_T:            return Event::KeyboardKey::T;
+        case SDLK_U:            return Event::KeyboardKey::U;
+        case SDLK_V:            return Event::KeyboardKey::V;
+        case SDLK_W:            return Event::KeyboardKey::W;
+        case SDLK_X:            return Event::KeyboardKey::X;
+        case SDLK_Y:            return Event::KeyboardKey::Y;
+        case SDLK_Z:            return Event::KeyboardKey::Z;
+#else
         case SDLK_a:            return Event::KeyboardKey::A;
         case SDLK_b:            return Event::KeyboardKey::B;
         case SDLK_c:            return Event::KeyboardKey::C;
@@ -71,6 +98,7 @@ namespace tgui
         case SDLK_x:            return Event::KeyboardKey::X;
         case SDLK_y:            return Event::KeyboardKey::Y;
         case SDLK_z:            return Event::KeyboardKey::Z;
+#endif
         case SDLK_0:            return Event::KeyboardKey::Num0;
         case SDLK_1:            return Event::KeyboardKey::Num1;
         case SDLK_2:            return Event::KeyboardKey::Num2;
@@ -243,6 +271,18 @@ namespace tgui
             }
             case SDL_EVENT_KEY_DOWN:
             {
+#if SDL_MAJOR_VERSION >= 3
+                const Event::KeyboardKey code = convertKeyCode(eventSDL.key.key);
+                if (code == Event::KeyboardKey::Unknown)
+                    return false; // This key isn't handled by TGUI
+
+                eventTGUI.type = Event::Type::KeyPressed;
+                eventTGUI.key.code = code;
+                eventTGUI.key.alt = ((eventSDL.key.mod & SDL_KMOD_ALT) != 0);
+                eventTGUI.key.control = ((eventSDL.key.mod & SDL_KMOD_CTRL) != 0);
+                eventTGUI.key.shift = ((eventSDL.key.mod & SDL_KMOD_SHIFT) != 0);
+                eventTGUI.key.system = ((eventSDL.key.mod & SDL_KMOD_GUI) != 0);
+#else
                 const Event::KeyboardKey code = convertKeyCode(eventSDL.key.keysym.sym);
                 if (code == Event::KeyboardKey::Unknown)
                     return false; // This key isn't handled by TGUI
@@ -253,6 +293,7 @@ namespace tgui
                 eventTGUI.key.control = ((eventSDL.key.keysym.mod & SDL_KMOD_CTRL) != 0);
                 eventTGUI.key.shift = ((eventSDL.key.keysym.mod & SDL_KMOD_SHIFT) != 0);
                 eventTGUI.key.system = ((eventSDL.key.keysym.mod & SDL_KMOD_GUI) != 0);
+#endif
                 return true;
             }
             case SDL_EVENT_MOUSE_WHEEL:
@@ -582,7 +623,11 @@ namespace tgui
             // We need to call SDL_StartTextInput here, but we reuse the updateTextCursorPosition code as it needs the same calculations
             updateTextCursorPosition(inputRect, {});
 
+#if SDL_MAJOR_VERSION >= 3
+            SDL_StartTextInput(m_window);
+#else
             SDL_StartTextInput();
+#endif
             m_textInputStarted = true;
 
             // For some weird reason the IME candidates window might remain on the old location when we move focus from
@@ -599,7 +644,11 @@ namespace tgui
     {
         if (m_textInputStarted)
         {
+#if SDL_MAJOR_VERSION >= 3
+            SDL_StopTextInput(m_window);
+#else
             SDL_StopTextInput();
+#endif
             m_textInputStarted = false;
         }
     }
@@ -636,15 +685,22 @@ namespace tgui
         const Vector2f topLeft = mapCoordsToPixel(inputRect.getPosition());
         const Vector2f bottomRight = mapCoordsToPixel(inputRect.getPosition() + inputRect.getSize());
         const Vector2f caretPosPixels = mapCoordsToPixel(caretPos);
-
+        SDL_Rect sdlRect;
+#if SDL_MAJOR_VERSION >= 3
+        sdlRect.x = static_cast<int>(std::round(topLeft.x / dpiScale));
+        sdlRect.y = static_cast<int>(std::round(topLeft.y / dpiScale));
+        sdlRect.w = static_cast<int>(std::round((bottomRight - topLeft).x / dpiScale));
+        sdlRect.h = static_cast<int>(std::round((bottomRight - topLeft).y / dpiScale));
+        SDL_SetTextInputArea(m_window, &sdlRect, static_cast<int>(std::round(caretPosPixels.x)));
+#else
         // SDL positions the IME window at the left side of the input rect, but we want the window to follow the caret.
         // So we set the left side of the rectangle to the current location of the caret.
-        SDL_Rect sdlRect;
         sdlRect.x = static_cast<int>(std::round(std::max(caretPosPixels.x, topLeft.x) / dpiScale));
         sdlRect.y = static_cast<int>(std::round(topLeft.y / dpiScale));
         sdlRect.w = static_cast<int>(std::round(std::max(caretPosPixels.x, (bottomRight - topLeft).x) / dpiScale));
         sdlRect.h = static_cast<int>(std::round((bottomRight - topLeft).y / dpiScale));
         SDL_SetTextInputRect(&sdlRect);
+#endif
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
