@@ -200,7 +200,10 @@ namespace tgui
                                                          {"TextColor", Color::Black}})},
                     {"Panel", RendererData::create({{"BorderColor", Color::Black},
                                                     {"BackgroundColor", Color::White}})},
-                    {"PanelListBox", RendererData::create({{"ItemsBackgroundColor", Color{245, 245, 245}},
+                    {"PanelListBox", RendererData::create({{"Borders", Borders{1}},
+                                                           {"BorderColor", Color::Black},
+                                                           {"BackgroundColor", Color::White},
+                                                           {"ItemsBackgroundColor", Color{245, 245, 245}},
                                                            {"ItemsBackgroundColorHover", Color::White},
                                                            {"SelectedItemsBackgroundColor", Color{0, 110, 255}},
                                                            {"SelectedItemsBackgroundColorHover", Color{30, 150, 255}}})},
@@ -718,7 +721,10 @@ namespace tgui
         for (auto pair : m_renderers)
         {
             const auto& renderer = pair.second;
-            for (auto& observer : renderer->observers)
+
+            // Make a copy of the observers because setRenderer alters the observers
+            auto observers = renderer->observers;
+            for (auto* observer : observers)
                 observer->setRenderer(renderer);
         }
 
