@@ -22,7 +22,6 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-
 #include <TGUI/Widgets/ColorPicker.hpp>
 #include <TGUI/Widgets/EditBox.hpp>
 #include <TGUI/Widgets/Label.hpp>
@@ -54,9 +53,6 @@ namespace tgui
         **/
         const auto fract = [](float x) { return x - std::floor(x); };
         const auto mix = [](float x, float y, float a) { return x * (1.0f - a) + y * a; };
-        const auto clamp = [](float x, float minVal, float maxVal) {
-            return std::min(std::max(x, minVal), maxVal);
-        };
 
         h = clamp(h, 0.f, 1.f);
         s = clamp(s, 0.f, 1.f);
@@ -72,9 +68,9 @@ namespace tgui
                            v * mix(K[0], clamp(p[1] - K[0], 0.f, 1.f), s),
                            v * mix(K[0], clamp(p[2] - K[0], 0.f, 1.f), s)};
 
-        return {static_cast<std::uint8_t>(clamp(255 * C[0], 0, 255)),
-                static_cast<std::uint8_t>(clamp(255 * C[1], 0, 255)),
-                static_cast<std::uint8_t>(clamp(255 * C[2], 0, 255))};
+        return {static_cast<std::uint8_t>(clamp(255.f * C[0], 0.f, 255.f)),
+                static_cast<std::uint8_t>(clamp(255.f * C[1], 0.f, 255.f)),
+                static_cast<std::uint8_t>(clamp(255.f * C[2], 0.f, 255.f))};
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -183,10 +179,10 @@ namespace tgui
         m_colorWheelSprite.setTexture(m_colorWheelTexture);
         pixels = nullptr;
 
-        m_red->setVerticalScroll(false);
-        m_green->setVerticalScroll(false);
-        m_blue->setVerticalScroll(false);
-        m_alpha->setVerticalScroll(false);
+        m_red->setOrientation(Orientation::Horizontal);
+        m_green->setOrientation(Orientation::Horizontal);
+        m_blue->setOrientation(Orientation::Horizontal);
+        m_alpha->setOrientation(Orientation::Horizontal);
         m_red->setWidth(200);
         m_green->setWidth(200);
         m_blue->setWidth(200);
@@ -222,7 +218,7 @@ namespace tgui
 
         add(m_value, "#TGUI_INTERNAL$ColorPickerValue#");
         m_value->setValue(m_value->getMaximum());
-        m_value->setVerticalScroll(true);
+        m_value->setOrientation(Orientation::Vertical);
         m_value->setHeight(200);
 
         add(Label::create("Last:"), "#TGUI_INTERNAL$ColorPickerLabelLast#");
