@@ -22,7 +22,6 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-
 #include <TGUI/Container.hpp>
 #include <TGUI/Widgets/EditBox.hpp>
 #include <TGUI/Keyboard.hpp>
@@ -851,7 +850,9 @@ namespace tgui
         }
         else if (property == U"CaretColorFocused")
         {
+TGUI_IGNORE_DEPRECATED_WARNINGS_START
             m_caretColorFocusedCached = getSharedRenderer()->getCaretColorFocused();
+TGUI_IGNORE_DEPRECATED_WARNINGS_END
         }
         else if (property == U"SelectedTextBackgroundColor")
         {
