@@ -22,11 +22,39 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-#include <TGUI/Widgets/CanvasBase.hpp>
+#include <TGUI/Config.hpp>
 
 #if TGUI_HAS_RENDERER_BACKEND_SFML_GRAPHICS
     #include <SFML/Graphics/View.hpp>
     #include <SFML/Graphics/Sprite.hpp>
+
+    #if TGUI_BUILD_AS_CXX_MODULE
+        #include <SFML/Graphics/RenderTexture.hpp>
+    #endif
+#endif
+#if TGUI_HAS_RENDERER_BACKEND_SDL_RENDERER
+    #include <TGUI/extlibs/IncludeSDL.hpp>
+#endif
+
+#if TGUI_BUILD_AS_CXX_MODULE
+    import tgui;
+    #if TGUI_HAS_RENDERER_BACKEND_SFML_GRAPHICS
+        import tgui.backend.renderer.sfml_graphics;
+    #endif
+    #if TGUI_HAS_RENDERER_BACKEND_SDL_RENDERER
+        import tgui.backend.renderer.sdl_renderer;
+    #endif
+    #if TGUI_HAS_RENDERER_BACKEND_OPENGL3
+        import tgui.backend.renderer.opengl3;
+    #endif
+    #if TGUI_HAS_RENDERER_BACKEND_GLES2
+        import tgui.backend.renderer.gles2;
+    #endif
+    #if TGUI_HAS_RENDERER_BACKEND_RAYLIB
+        import tgui.backend.renderer.raylib;
+    #endif
+#else
+    #include <TGUI/Widgets/CanvasBase.hpp>
 #endif
 
 #include "Tests.hpp"
@@ -50,9 +78,7 @@ static void testCanvasCommon(tgui::CanvasBase::Ptr canvas)
 
 #if TGUI_HAS_RENDERER_BACKEND_SFML_GRAPHICS
 
-#if TGUI_BUILD_AS_CXX_MODULE
-    import tgui.backend.renderer.sfml_graphics;
-#else
+#if !TGUI_BUILD_AS_CXX_MODULE
     #include <TGUI/Backend/Renderer/SFML-Graphics/CanvasSFML.hpp>
     #include <TGUI/Backend/Renderer/SFML-Graphics/BackendRendererSFML.hpp>
 #endif
@@ -140,9 +166,14 @@ TEST_CASE("[CanvasSFML]")
             canvas->setSize({180, 140});
             canvas->setPosition({10, 5});
 
+#if SFML_VERSION_MAJOR >= 3
+            auto optionalTexture = sf::Texture::loadFromFile("resources/image.png");
+            REQUIRE(optionalTexture);
+            sf::Texture texture = std::move(*optionalTexture);
+#else
             sf::Texture texture;
             REQUIRE(texture.loadFromFile("resources/image.png"));
-
+#endif
             sf::Sprite sprite(texture);
             sprite.setScale({150.f / texture.getSize().x, 100.f / texture.getSize().y});
             sprite.setPosition({15, 20});
@@ -172,9 +203,7 @@ TEST_CASE("[CanvasSFML]")
 
 #if TGUI_HAS_RENDERER_BACKEND_SDL_RENDERER
 
-#if TGUI_BUILD_AS_CXX_MODULE
-    import tgui.backend.renderer.sdl_renderer;
-#else
+#if !TGUI_BUILD_AS_CXX_MODULE
     #include <TGUI/Backend/Renderer/SDL_Renderer/CanvasSDL.hpp>
     #include <TGUI/Backend/Renderer/SDL_Renderer/BackendRendererSDL.hpp>
 #endif
@@ -229,9 +258,7 @@ TEST_CASE("[CanvasSDL]")
 
 #if TGUI_HAS_RENDERER_BACKEND_OPENGL3
 
-#if TGUI_BUILD_AS_CXX_MODULE
-    import tgui.backend.renderer.opengl3;
-#else
+#if !TGUI_BUILD_AS_CXX_MODULE
     #include <TGUI/Backend/Renderer/OpenGL3/CanvasOpenGL3.hpp>
     #include <TGUI/Backend/Renderer/OpenGL3/BackendRendererOpenGL3.hpp>
 #endif
@@ -270,9 +297,7 @@ TEST_CASE("[CanvasOpenGL3]")
 
 #if TGUI_HAS_RENDERER_BACKEND_GLES2
 
-#if TGUI_BUILD_AS_CXX_MODULE
-    import tgui.backend.renderer.gles2;
-#else
+#if !TGUI_BUILD_AS_CXX_MODULE
     #include <TGUI/Backend/Renderer/GLES2/CanvasGLES2.hpp>
     #include <TGUI/Backend/Renderer/GLES2/BackendRendererGLES2.hpp>
 #endif
@@ -308,3 +333,42 @@ TEST_CASE("[CanvasGLES2]")
     }
 }
 #endif
+
+#if TGUI_HAS_RENDERER_BACKEND_RAYLIB
+
+#if !TGUI_BUILD_AS_CXX_MODULE
+    #include <TGUI/Backend/Renderer/Raylib/CanvasRaylib.hpp>
+    #include <TGUI/Backend/Renderer/Raylib/BackendRendererRaylib.hpp>
+#endif
+
+TEST_CASE("[CanvasRaylib]")
+{
+    if (std::dynamic_pointer_cast<tgui::BackendRendererRaylib>(tgui::getBackend()->getRenderer()))
+    {
+        tgui::CanvasRaylib::Ptr canvas = tgui::CanvasRaylib::create();
+        canvas->getRenderer()->setFont("resources/DejaVuSans.ttf");
+
+        SECTION("WidgetType")
+        {
+            REQUIRE(canvas->getWidgetType() == "CanvasRaylib");
+        }
+
+        SECTION("constructor")
+        {
+            canvas = tgui::CanvasRaylib::create({200, 100});
+            REQUIRE(canvas->getSize() == tgui::Vector2f(200, 100));
+        }
+
+        testCanvasCommon(canvas);
+
+        testWidgetRenderer(canvas->getRenderer());
+
+        SECTION("Saving and loading from file")
+        {
+            REQUIRE_NOTHROW(canvas = tgui::CanvasRaylib::create({60, 40}));
+
+            testSavingWidget("CanvasRaylib", canvas, false);
+        }
+    }
+}
+#endif
